package es.ua.j2ee.notas;

import javax.microedition.midlet.*;
import javax.microedition.lcdui.*;

public class ListaNotas extends List implements CommandListener, NotasListener {

	MIDlet owner;

	Command cmdMem;
	Command cmdVer;
	Command cmdNueva;
	Command cmdEditar;
	Command cmdBorrar;
	
	Notas notas;

	public ListaNotas(MIDlet owner, Notas notas) {
		super("Notas", Choice.IMPLICIT);
		
		this.owner = owner;
		this.notas = notas;
		
		notas.addNotasListener(this);
		
		// Crea lista de notas
		for(int i=0;i<notas.numNotas();i++) {
			this.append(notas.getNota(i).nombre, null);
		}
		
		// Aade comandos
		cmdVer = new Command("Ver", Command.ITEM, 1);
		cmdNueva = new Command("Nueva", Command.SCREEN, 1);
		cmdMem = new Command("Memoria", Command.SCREEN, 1);
		cmdEditar = new Command("Editar", Command.ITEM, 1);
		cmdBorrar = new Command("Borrar", Command.ITEM, 1);
		this.addCommand(cmdVer);
		this.addCommand(cmdMem);
		this.addCommand(cmdNueva);
		this.addCommand(cmdEditar);
		this.addCommand(cmdBorrar);
		this.setCommandListener(this);
	}

	public void commandAction(Command cmd, Displayable disp) {
		if(cmd == List.SELECT_COMMAND || cmd == cmdVer) {
			
			// Elimina una nota
			int indice = this.getSelectedIndex();
			if(indice != -1) {
				VerNota vn = new VerNota(owner, this, notas.getNota(indice));
				Display d = Display.getDisplay(owner);
				d.setCurrent(vn);
			} else {
				Alert a = new Alert("Error", "No hay ninguna nota seleccionada", null, AlertType.ERROR);
				Display d = Display.getDisplay(owner);
				d.setCurrent(a, d.getCurrent());
			}
			
		} else if(cmd == cmdMem) {

			// Muestra informacion sobre la memoria de RMS
			try {
				VerInfo vi = new VerInfo(owner, this, notas);
				Display d = Display.getDisplay(owner);
				d.setCurrent(vi);
			} catch(Exception e) {
				Alert a = new Alert("Error", "No se puede acceder a RMS", null, AlertType.ERROR);
				Display d = Display.getDisplay(owner);
				d.setCurrent(a, d.getCurrent());
			}
			
		} else if(cmd == cmdNueva) {

			// Aade una nueva nota
			EdicionNota en = new EdicionNota(owner, this, notas);

			Display d = Display.getDisplay(owner);
			Displayable previo = d.getCurrent();
			d.setCurrent(en);


		} else if(cmd == cmdEditar) {

			// Edita una nota
			int indice = this.getSelectedIndex();
			if(indice != -1) {

				EdicionNota en = new EdicionNota(owner, this, notas, indice);

				Display d = Display.getDisplay(owner);
				Displayable previo = d.getCurrent();
				d.setCurrent(en);

			} else {
				Alert a = new Alert("Error", "No hay ninguna nota seleccionada", null, AlertType.ERROR);
				Display d = Display.getDisplay(owner);
				d.setCurrent(a, d.getCurrent());
			}
			
		} else if(cmd == cmdBorrar) {

			// Elimina una nota
			int indice = this.getSelectedIndex();
			if(indice != -1) {
				Thread t = new Thread(new EliminaNota(indice));
				t.start();
			} else {
				Alert a = new Alert("Error", "No hay ninguna nota seleccionada", null, AlertType.ERROR);
				Display d = Display.getDisplay(owner);
				d.setCurrent(a, d.getCurrent());
			}
		}
	}

	// Eventos de modificacion de notas

	public void notaCreada(Nota nota) {
		this.append(nota.nombre, null);
	}
	
	public void notaEliminada(int indice) {
		this.delete(indice);
	}
	
	public void notaModificada(int indice, Nota nota) {
		this.set(indice, nota.nombre, null);		
	}

	// Abre la pantalla de confirmacion para la eliminacion

	class EliminaNota implements Runnable {

		int nota;

		public EliminaNota(int nota) {
			this.nota = nota;
		}

		public void run() {
			Confirmacion c = new Confirmacion(owner, "Se va a eliminar la nota " + notas.getNota(nota).nombre + ", esta seguro?");

			Display d = Display.getDisplay(owner);
			Displayable previo = d.getCurrent();
			d.setCurrent(c);

			if(c.acepta()) {
				try {
					notas.eliminaNota(nota);
				} catch(Exception e) {
					Alert a = new Alert("Error", "No se puede eliminar", null, AlertType.ERROR);
					d.setCurrent(a, previo);
					return;					
				}
				
			}

			d.setCurrent(previo);
		}
	}

}
